
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libk3blib.so.6 )
( cd usr/lib ; ln -sf libk3blib.so.6.0.0 libk3blib.so.6 )
( cd usr/lib ; rm -rf libk3blib.so )
( cd usr/lib ; ln -sf libk3blib.so.6 libk3blib.so )
( cd usr/lib ; rm -rf libk3bdevice.so )
( cd usr/lib ; ln -sf libk3bdevice.so.6 libk3bdevice.so )
( cd usr/lib ; rm -rf libk3bdevice.so.6 )
( cd usr/lib ; ln -sf libk3bdevice.so.6.0.0 libk3bdevice.so.6 )
( cd usr/share/doc/HTML/uk/k3b ; rm -rf common )
( cd usr/share/doc/HTML/uk/k3b ; ln -sf /usr/share/doc/HTML/uk//common common )
( cd usr/share/doc/HTML/sv/k3b ; rm -rf common )
( cd usr/share/doc/HTML/sv/k3b ; ln -sf /usr/share/doc/HTML/sv//common common )
( cd usr/share/doc/HTML/fr/k3b ; rm -rf common )
( cd usr/share/doc/HTML/fr/k3b ; ln -sf /usr/share/doc/HTML/fr//common common )
( cd usr/share/doc/HTML/nl/k3b ; rm -rf common )
( cd usr/share/doc/HTML/nl/k3b ; ln -sf /usr/share/doc/HTML/nl//common common )
( cd usr/share/doc/HTML/pt_BR/k3b ; rm -rf common )
( cd usr/share/doc/HTML/pt_BR/k3b ; ln -sf /usr/share/doc/HTML/pt_BR//common common )
( cd usr/share/doc/HTML/pt/k3b ; rm -rf common )
( cd usr/share/doc/HTML/pt/k3b ; ln -sf /usr/share/doc/HTML/pt//common common )
( cd usr/share/doc/HTML/en/k3b ; rm -rf common )
( cd usr/share/doc/HTML/en/k3b ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/et/k3b ; rm -rf common )
( cd usr/share/doc/HTML/et/k3b ; ln -sf /usr/share/doc/HTML/et//common common )
( cd usr/share/doc/HTML/es/k3b ; rm -rf common )
( cd usr/share/doc/HTML/es/k3b ; ln -sf /usr/share/doc/HTML/es//common common )
( cd usr/share/doc/HTML/de/k3b ; rm -rf common )
( cd usr/share/doc/HTML/de/k3b ; ln -sf /usr/share/doc/HTML/de//common common )
